@@ -58,13 +58,10 @@ def update_memory(run_instance):
     if run_instance.steps != steps \
             or run_instance.memory.batch_size != batch_size \
             or run_instance.memory.memory_size != memory_size:
-        assert not run_instance.memory.use_dataloader, "Dataloaders not implemented in this checkpoint updater."
-        from tmrl.memory_dataloading import MemoryBatchSampler
         run_instance.steps = steps
         run_instance.memory.nb_steps = steps
         run_instance.memory.batch_size = batch_size
         run_instance.memory.memory_size = memory_size
-        run_instance.memory._batch_sampler = MemoryBatchSampler(data_source=run_instance.memory, nb_steps=steps, batch_size=batch_size)
         logging.info(f"Memory updated with steps:{steps}, batch size:{batch_size}, memory size:{memory_size}.")
     return run_instance
 
